]> git.ipfire.org Git - thirdparty/bash.git/blobdiff - pathexp.h
bash-5.1 distribution sources and documentation
[thirdparty/bash.git] / pathexp.h
index adef8b2a169a5f66bed4b7ea5c6c40946a48ee4d..7ed0d2ad6904be1c8873073465f67b87b35030ec 100644 (file)
--- a/pathexp.h
+++ b/pathexp.h
@@ -1,6 +1,6 @@
 /* pathexp.h -- The shell interface to the globbing library. */
 
-/* Copyright (C) 1987-2015 Free Software Foundation, Inc.
+/* Copyright (C) 1987-2020 Free Software Foundation, Inc.
 
    This file is part of GNU Bash, the Bourne Again SHell.
 
@@ -52,7 +52,7 @@ extern int extended_glob;
 extern int glob_star;
 extern int match_ignore_case;  /* doesn't really belong here */
 
-extern int unquoted_glob_pattern_p __P((char *));
+extern int unquoted_glob_pattern_p PARAMS((char *));
 
 /* PATHNAME can contain characters prefixed by CTLESC; this indicates
    that the character is to be quoted.  We quote it here in the style
@@ -64,13 +64,15 @@ extern int unquoted_glob_pattern_p __P((char *));
    pattern while executing a case statement), flags should include
    QGLOB_CVTNULL.  If flags includes QGLOB_FILENAME, appropriate quoting
    to match a filename should be performed. */
-extern char *quote_string_for_globbing __P((const char *, int));
+extern char *quote_string_for_globbing PARAMS((const char *, int));
 
-extern int glob_char_p __P((const char *));
-extern char *quote_globbing_chars __P((const char *));
+extern int glob_char_p PARAMS((const char *));
+extern char *quote_globbing_chars PARAMS((const char *));
 
-/* Call the glob library to do globbing on PATHNAME. */
-extern char **shell_glob_filename __P((const char *));
+/* Call the glob library to do globbing on PATHNAME. FLAGS is additional
+   flags to pass to QUOTE_STRING_FOR_GLOBBING, mostly having to do with
+   whether or not we've already performed quote removal. */
+extern char **shell_glob_filename PARAMS((const char *, int));
 
 /* Filename completion ignore.  Used to implement the "fignore" facility of
    tcsh, GLOBIGNORE (like ksh-93 FIGNORE), and EXECIGNORE.
@@ -86,7 +88,7 @@ struct ign {
   int len, flags;
 };
 
-typedef int sh_iv_item_func_t __P((struct ign *));
+typedef int sh_iv_item_func_t PARAMS((struct ign *));
 
 struct ignorevar {
   char *varname;       /* FIGNORE, GLOBIGNORE, or EXECIGNORE */
@@ -96,10 +98,10 @@ struct ignorevar {
   sh_iv_item_func_t *item_func; /* Called when each item is parsed from $`varname' */
 };
 
-extern void setup_ignore_patterns __P((struct ignorevar *));
+extern void setup_ignore_patterns PARAMS((struct ignorevar *));
 
-extern void setup_glob_ignore __P((char *));
-extern int should_ignore_glob_matches __P((void));
-extern void ignore_glob_matches __P((char **));
+extern void setup_glob_ignore PARAMS((char *));
+extern int should_ignore_glob_matches PARAMS((void));
+extern void ignore_glob_matches PARAMS((char **));
 
 #endif